/*This do-file joins the corrected ParlGov and CMP datasets.
Please read the documentation provided for details.
Please note that you have to install the "carryforward" 
command for this script to run smoothly.
Please cite when using this code or resulting estimates:

Wratil, Christopher. 2022. CMP Government Positions Data. Version 2.2.

Volkens, Andrea et al. 2019. The Manifesto Data Collection. Manifesto Project (MRG/CMP/MARPOR). Version 2019b.

Döring, Holger, and Philip Manow. 2019. Parliaments and Governments Database (ParlGov): Information on Parties, Elections and Cabinets in Modern Democracies. Development Version.

*/

//Set your working directory to the directory with the files
//cd "SET YOUR DIRECTORY"

//Get data on governments' ideological positions from CMP
insheet using  "./parlgov_cabinets.csv", clear 

//Streamline country labels
gen country = .
replace country = 8 if country_name == "Greece"
replace country = 28 if country_name == "United Kingdom"
replace country = 9 if country_name == "Spain"
replace country = 5 if country_name == "Germany"
replace country = 18 if country_name == "Malta"
replace country = 2 if country_name == "Bulgaria"
replace country = 20 if country_name == "Austria"
replace country = 1 if country_name == "Belgium"
replace country = 13 if country_name == "Cyprus"
replace country = 3 if country_name == "Czech Republic"
replace country = 4 if country_name == "Denmark"
replace country = 6 if country_name == "Estonia"
replace country = 26 if country_name == "Finland"
replace country = 10 if country_name == "France"
replace country = 17 if country_name == "Hungary"
replace country = 7 if country_name == "Ireland"
replace country = 12 if country_name == "Italy"
replace country = 14 if country_name == "Latvia"
replace country = 15 if country_name == "Lithuania"
replace country = 16 if country_name == "Luxembourg"
replace country = 19 if country_name == "Netherlands"
replace country = 21 if country_name == "Poland"
replace country = 22 if country_name == "Portugal"
replace country = 23 if country_name == "Romania"
replace country = 24 if country_name == "Slovenia"
replace country = 25 if country_name == "Slovakia"
replace country = 27 if country_name == "Sweden"
replace country = 11 if country_name == "Croatia"

//Drop all other data
keep if country != .

save "./aux_data.dta", replace

//Get party id for CMP
insheet using "./parlgov_parties.csv", clear 

merge 1:m party_id using "./aux_data.dta"
drop _merge

//Get rid of improper parties
drop if party_name == "no party affiliation"
drop if party_name == "parteilos"
drop if party_name == "partilˆs"
drop if party_name == "f¸ggetlen"
drop if party_name == "divers"
drop if party_name == "divers droite"
drop if party_name == "divers gauche"
drop if party_name == "diversi"
drop if party_name == "joint candidates"
drop if party_name == "extrÍme droite"
drop if party_name == "extrÍme gauche"

//Prepare cabinets data
gen date = date(start_date, "DMY")
gen election = date(election_date, "DMY")
gen year = year(date)
//Assume all parties are forming a government in case of caretaker cabinets that are entirely technocratic
egen tech = sum(cabinet_party) if seats > 0, by(country date)
egen technocratic = sum(tech), by(country date)
replace cabinet_party = 1 if caretaker == 1 & technocratic == 0
//Drop data before 1988 and countries not in sample
drop if year < 1988
drop if country == .
//Sum seats for groups of electoral parties covered by same CMP code
egen sum_seats = sum(seats) if cmp != ., by(cmp start_date)
replace seats = sum_seats if cmp != .
//Replace party id and prime minister affiliation where CMP uses a single code
sort cmp party_id
by cmp: replace party_id = party_id[_n-1] if cmp==cmp[_n-1] & cmp != .
egen pm = max(prime_minister), by(cmp start_date)
replace prime_minister = pm
//Drop unnecessary variables
keep prime_minister party_id date seats cabinet_party cabinet_name country cmp family_name election election_s caretaker eu_anti_pro left_right
//Detect duplicates
sort party_id date
quietly by party_id date:  gen dup = cond(_N==1,0,_n)
sort dup
//Drop observations with party name change
drop if dup > 1
drop dup

//Create cabinet number identifier
sort country date
quietly by country date:  gen dup = cond(_N==1,0,_n)
gen date_aux = date
replace date_aux = . if dup > 1
by country: egen number = rank(date_aux)
by country: egen no_cabinet = max(number)
by country date: egen cabinet_id = mean(number)
drop dup date_aux number
drop if cabinet_id == .

//Create time series cross section and fill in times when parties were not in parliament
tsset party_id cabinet_id
tsfill, full
sort party_id cabinet_id
by party_id: replace country = country[_n-1] if country >= .
gsort party_id -cabinet_id
by party_id: replace country = country[_n-1] if country >= .
sort party_id cabinet_id
by party_id: replace cmp = cmp[_n-1] if cmp >= .
gsort party_id -cabinet_id
by party_id: replace cmp = cmp[_n-1] if cmp >= .
sort party_id cabinet_id
by party_id: replace family_name = family_name[_n-1] if family_name == ""
gsort party_id -cabinet_id
by party_id: replace family_name = family_name[_n-1] if family_name == ""
sort country
by country: egen no_cabinet_aux = mean(no_cabinet)
drop if cabinet_id > no_cabinet_aux
replace no_cabinet = no_cabinet_aux if no_cabinet == .
egen mean_date = mean(date), by(country cabinet_id)
replace date = mean_date if date == .
egen mean_election = mean(election), by(country cabinet_id)
replace election = mean_election if election == .
drop no_cabinet_aux mean_date mean_election

//Change supporting government parties back to opposition (for part of the data "2" was used as code for supporting parties that were hand-coded)
replace cabinet_party = 0 if cabinet_party == 2

//Recode cabinet party variable to include times out of parliament
recode cabinet_party (. = 0 "Out of parliament") (0 = 1 "In opposition") (1 = 2 "In government"), gen(party_status)

//Set seats to 0 if party is not in parliament
replace seats = 0 if seats == .

//Creating last observation (1st of January 2019)
expand 2 if no_cabinet == cabinet_id, gen(duplicate)
replace date = mdy(1, 1, 2019) if duplicate == 1
replace cabinet_id = . if duplicate == 1
drop duplicate 

//Save cabinets data
gen year = year(election)
save "./aux_data.dta", replace

//Prepare CMP data for merging
insheet using  "./cmp_data_modified.csv", clear 
rename party cmp
gen election = date(edate, "YMD")
gen year = year(election)
drop if year < 1988
gen eu = per108 - per110 
replace rile = (per104 + per201 + per203 + per305 + per401 + per402 + per407 + per414 + per505 + per601 + per603 + per605 + per606) - (per103 + per105 + per106 + per107 + per403 + per404 + per406 + per412 + per413 + per504 + per506 + per701 + per202) 
gen free_market = (per401 + per402) - (per403 + per412 + per413 + per415) 
gen state_involvement = (per401 + per402 + per407 + per414 + per505) - (per403 + per404 + per406 + per412 + per413 + per504 + per506 + per701)
gen planned_economy = (per401 + per414) - (per403 + per404 + per412)
//HERE YOU CAN INCLUDE NEW MEASURES FROM THE CMP CATEGORIES

//Drop unnecessary variables
keep rile eu cmp year election countryname planeco markeco welfare free_market state_involvement planned_economy
//YOUR NEW MEASURE MUST APPEAR IN THE LIST ABOVE

//Merge with cabinets data
merge 1:m election cmp using "./aux_data.dta"
drop if _merge == 1

//Create indicator of CMP missingness
gen missing_cmp_gov = 0
replace missing_cmp_gov = 1 if _merge == 2
drop _merge

//Create time series observations
gen cabinet_date = date
sort party_id date
tsset party_id date
tsfill

//Interpolate CMP positions
sort party_id date
bysort party_id: carryforward cabinet_date, gen(cabinet_start_date)
bysort party_id: carryforward rile, gen(gov_lr_cmp_static)
bysort party_id: carryforward eu, gen(gov_eu_cmp_static)
bysort party_id: carryforward missing_cmp, replace
bysort party_id: carryforward country, replace
bysort party_id: carryforward cabinet_name, replace
bysort party_id: carryforward seats, replace
bysort party_id: carryforward election_s, replace
bysort party_id: carryforward caretaker, replace
bysort party_id: carryforward party_status, replace
bysort party_id: carryforward family_name, replace
bysort party_id: carryforward prime_minister, replace
bysort party_id: carryforward planeco, gen(gov_planeco_cmp_static)
bysort party_id: carryforward markeco, gen(gov_markeco_cmp_static)
bysort party_id: carryforward welfare, gen(gov_welfare_cmp_static)
bysort party_id: carryforward free_market, gen(gov_free_market_cmp_static)
bysort party_id: carryforward state_involvement, gen(gov_state_involvement_cmp_static)
bysort party_id: carryforward planned_economy, gen(gov_planned_economy_cmp_static)
//YOU NEED TO INSERT A LINE SIMILAR TO LINE 206 FOR YOUR NEW MEASURE

//Change to missing where CMP data is missing
replace gov_lr_cmp_static = . if missing_cmp_gov == 1
replace gov_eu_cmp_static = . if missing_cmp_gov == 1
replace gov_planeco_cmp_static = . if missing_cmp_gov == 1
replace gov_markeco_cmp_static = . if missing_cmp_gov == 1
replace gov_welfare_cmp_static = . if missing_cmp_gov == 1
replace gov_free_market_cmp_static = . if missing_cmp_gov == 1
replace gov_state_involvement_cmp_static = . if missing_cmp_gov == 1
replace gov_planned_economy_cmp_static = . if missing_cmp_gov == 1
//YOU NEED TO INSERT A LINE SIMILAR TO LINE 217 FOR YOUR NEW MEASURE

//Create party family variable
tab family_name, gen(family_gov)

//Collapsing data
//Get rid of non-informative observations
drop if party_status != 2
//Collapse data preserving indicators of missingness
collapse (mean)  gov_planned_economy_cmp_static gov_free_market_cmp_static gov_state_involvement_cmp_static gov_markeco_cmp_static gov_planeco_cmp_static gov_welfare_cmp_static caretaker gov_eu_cmp_static gov_lr_cmp_static family_gov* missing_cmp_gov cabinet_start_date (firstnm) cabinet_name [aweight = seats] if party_status == 2, by(country date)
//YOUR NEW MEASURE MUST APPEAR IN THE LIST ABOVE
//Set to missing where more than 25% of government seats are missing - removes Di Rupo II and Michel II (French-speaking parties not coded)
replace gov_lr_cmp_static = . if missing_cmp_gov > 0.25
replace gov_eu_cmp_static = . if missing_cmp_gov > 0.25
replace gov_markeco_cmp_static = . if missing_cmp_gov > 0.25
replace gov_planeco_cmp_static = . if missing_cmp_gov > 0.25
replace gov_welfare_cmp_static = . if missing_cmp_gov > 0.25
replace gov_free_market_cmp_static = . if missing_cmp_gov > 0.25
replace gov_state_involvement_cmp_static = . if missing_cmp_gov > 0.25
replace gov_planned_economy_cmp_static = . if missing_cmp_gov > 0.25
//YOU NEED TO INSERT A LINE SIMILAR TO LINE 237 FOR YOUR NEW MEASURE

//Generate year variable
gen year = year(date)

//Labelling and formatting data
label variable country "Country"
label define country 1 "Belgium" 2 "Bulgaria" 3 "Czech Republic" 4 "Denmark" 5 "Germany" 6 "Estonia" 7 "Ireland" 8 "Greece" 9 "Spain" 10 "France" 11 "Croatia" 12 "Italy" 13 "Cyprus" 14 "Latvia" 15 "Lithuania" 16 "Luxembourg" 17 "Hungary" 18 "Malta" 19 "Netherlands" 20 "Austria" 21 "Poland" 22 "Portugal" 23 "Romania" 24 "Slovenia" 25 "Slovakia" 26 "Finland" 27 "Sweden" 28 "United Kingdom", replace
label values country country

label variable date "Date"
format date %d

label variable gov_eu_cmp_static "Cabinet parties' position on EU integration (weighted)"
label variable gov_lr_cmp_static "Cabinet parties' position on left-right (weighted)"
label variable gov_planeco_cmp_static "Cabinet parties' position on CMP's planeco dimension"
label variable gov_markeco_cmp_static "Cabinet parties' position on CMP's markeco dimension"
label variable gov_welfare_cmp_static "Cabinet parties' position on CMP's welfare dimension"
label variable gov_planned_economy_cmp_static "Cabinet parties' position on planned vs. free economy dimension (Lowe et al. 2011)"
label variable gov_free_market_cmp_static "Cabinet parties' position on free market economy dimension (Lowe et al. 2011)"
label variable gov_state_involvement_cmp_static "Cabinet parties' position on state involvement in economy dimension (Benoit & Laver 2007)"
//YOU NEED TO INSERT A LINE SIMILAR TO LINE 258 FOR YOUR NEW MEASURE

label variable missing_cmp_gov "Share of cabinet parties' seats with CMP data missing"
label variable year "Year"

label variable cabinet_name "Nickname of cabinet"

//Create online version 2.1
drop if date < date("01/01/1993", "DMY")
drop if date > date("31/12/2018", "DMY")
keep cabinet_name country date gov_lr_cmp_static gov_eu_cmp_static gov_planeco_cmp_static gov_markeco_cmp_static gov_welfare_cmp_static gov_planned_economy_cmp_static gov_free_market_cmp_static gov_state_involvement_cmp_static
//YOUR NEW MEASURE MUST APPEAR IN THE LIST ABOVE

save "./parties_cmp2019_online_2.2.dta", replace
